//! Additional serde [`Deserialize`](serde::Deserialize)
//! implementations.
//!
//! Use these deserializers with the `#[serde(with = "...")]`
//! attribute:
//!
//! ```
//! #[derive(Deserialize)]
//! struct Config {
//!     #[serde(with = "crate::de::url")]
//!     url: url::Url,
//! }
//! ```

/// Deserialize [`Url`](::url::Url).
pub mod url {
    use serde::{Deserialize, Deserializer};

    pub fn deserialize<'de, D>(d: D) -> Result<url::Url, D::Error>
    where
        D: Deserializer<'de>,
    {
        let url = String::deserialize(d)?;
        let url: url::Url = url.parse().map_err(serde::de::Error::custom)?;
        Ok(url)
    }
}
